==> haskell-oeis-0.3.10-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-oeis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 oeis
version:              0.3.10
visibility:           public
id:                   oeis-0.3.10-ATscj8nKptRKNwbDgbVjB8
key:                  oeis-0.3.10-ATscj8nKptRKNwbDgbVjB8
license:              BSD-3-Clause
maintainer:           Bartosz Nitka <niteria@gmail.com>
author:               Brent Yorgey
stability:            experimental
synopsis:
    Interface to the Online Encyclopedia of Integer Sequences (OEIS)

description:
    Interface to the <http://oeis.org/ Online Encyclopedia of Integer Sequences (OEIS)>.

category:             Math
abi:                  fcddf64c955fc43a8e1d00a9059d256d
exposed:              True
exposed-modules:      Math.OEIS Math.OEIS.Internal
hidden-modules:       Math.OEIS.Types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/oeis-0.3.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/oeis-0.3.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-oeis
hs-libraries:         HSoeis-0.3.10-ATscj8nKptRKNwbDgbVjB8
depends:
    HTTP-4000.4.1-1tZQqEga02TAOb4VxjOGhF base-4.16.4.0
    network-3.1.4.0-3UsgZVPxzJR3pZOZAOsXvy
    network-uri-2.6.4.2-BC3te0GfpncIdQCU8I2AdS

haddock-interfaces:   /usr/share/doc/haskell-oeis/html/oeis.haddock
haddock-html:         /usr/share/doc/haskell-oeis/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-oeis-0.3.10-214-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-oeis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 oeis
version:              0.3.10
visibility:           public
id:                   oeis-0.3.10-9vPEfmg7VtDFCP3NUtzyg4
key:                  oeis-0.3.10-9vPEfmg7VtDFCP3NUtzyg4
license:              BSD-3-Clause
maintainer:           Bartosz Nitka <niteria@gmail.com>
author:               Brent Yorgey
stability:            experimental
synopsis:
    Interface to the Online Encyclopedia of Integer Sequences (OEIS)

description:
    Interface to the <http://oeis.org/ Online Encyclopedia of Integer Sequences (OEIS)>.

category:             Math
abi:                  275fb002497bf323a6dfff1b72fc8ed6
exposed:              True
exposed-modules:      Math.OEIS Math.OEIS.Internal
hidden-modules:       Math.OEIS.Types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/oeis-0.3.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/oeis-0.3.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-oeis
hs-libraries:         HSoeis-0.3.10-9vPEfmg7VtDFCP3NUtzyg4
depends:
    HTTP-4000.4.1-6GalKlUpmfECumsP7AWV7U base-4.16.4.0
    network-3.1.4.0-3UsgZVPxzJR3pZOZAOsXvy
    network-uri-2.6.4.2-BC3te0GfpncIdQCU8I2AdS

haddock-interfaces:   /usr/share/doc/haskell-oeis/html/oeis.haddock
haddock-html:         /usr/share/doc/haskell-oeis/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
